#!/usr/bin/perl

#http://www.the7soft.com/file-formats/file-formats-Text/file-formats.html

$titlehtm = 'Table 3: Which Asymmetry (a=-0.40 b=-9.0)';
$titletex = 'Which Asymmetry (a=-0.40 b=-9.0)';
$datafile = 'grid_T3.dat' ;
@lambda_xyk  = ('-0.015', '-0.012','-0.012','0.012','0.012','0.015');
@lambda_zyk  = ('0.100', '0.120','0.140','-0.140','-0.120','-0.100');
@lambda_xzyk = ('(-0.015, 0.100)', '(-0.012, 0.120)','(-0.012, 0.140)','(0.012, -0.140)','(0.012, -0.120)','(0.015,-0.100)');
$imax = 1 ;
$jmax = 6 ;

open(FILE,"$datafile");
@LINES = <FILE>;
close(FILE);

$string = join(' ',@LINES);
$string =~ s/\n//g;

@records = split(/\s*CaseNo = [0-9]+\s*/,$string) ;

write_table_tex() ;
#write_table_htm() ;


exit ;

sub write_table_tex {
    write_tabhead_tex() ;
    for($i = 0; $i < $imax; $i++) {
	write_rowhead_tex() ;
	for($j = 0; $j < $jmax; $j++) {
	    $idx = 1 + $i + $j*$imax ;
	    print "&\n";
	    write_rec_tex($records[$idx]) ;	
	}
	print "\\\\ \\hline\n";
    }
    write_tabtail_tex() ;
}

sub write_tabhead_tex {
    print "\\documentclass{article}\\begin{document}\n" ;
    print "\\begin{table}\\centering\n";
    print "\\caption{$titletex}\n";
    print "\\begin{tabular}{|c|c|c|c|c|c|c|c|c|}\\hline\n";
    for($j = 0; $j < $jmax; $j++) {
	print "& \$\\lambda_x^{y^k}=$lambda_xyk[$j]\$";
    }
    print "\\\\ \n";
    for($j = 0; $j < $jmax; $j++) {
	print "& \$\\lambda_z^{y^k}=$lambda_zyk[$j]\$";
    }
    print "\\\\ \\hline\n" ;
}

sub write_tabtail_tex {
    print "\\end{tabular}\n" ;
    print "\\end{table}" ;
    print "\\end{document}\n" ;
}

sub write_rowhead_tex {
    print "\\begin{tabular}{l}\$P/D\$\\\\" ;
    print "\$\\sigma_{P/D}\$\\\\" ;
    print "\$R\$\\\\" ;
    print "\$\\sigma_{R}\$\\\\" ;
    print "\$r_f\$\\\\" ;
    print "\$\\sigma_{r_f}\$\\\\" ;
    print "\$ep\$\\\\" ;
    print "\$corr(R,x)\$\\\\" ;
    print "\$Sharpe\$\\\\\\end{tabular}\n" ;
}
sub write_rec_tex {
    $string = $_[0] ;
    ($NOB,$PD,$R,$rf,$ep,$SPD,$SR,$Srf,$Sep,$corr,$sha)
    	= split(/\s+/,$string) ;
    if(defined($R)) {
	printf 
	"\\begin{tabular}{c}%1.2f\\\\%1.2f\\\\%1.2f\\\\%1.2f\\\\%1.2f\\\\%1.2f\\\\%1.2f\\\\%1.2f\\\\%1.2f\\end{tabular}\n",
        $PD,$SPD,$R,$SR,$rf,$Srf,$ep,$corr,$sha;
    } else {
	print "\\begin{tabular}{c}unstable\\end{tabular}\n" ;
    }
}


sub write_table_htm {
    write_tabhead_htm() ;
    for($i = 0; $i < $imax; $i++) {
	write_rowhead_htm() ;
	for($j = 0; $j < $jmax; $j++) {
	    $idx = 1 + $i + $j*$imax ;
	    write_rec_htm($records[$idx]) ;	
	}
	print "</tr>\n";
    }
    write_tabtail_htm() ;
}
sub write_tabhead_htm {
    print "<html><body>\n" ;
    print "<h3>$titlehtm</h3>\n" ;
    print "<table border=1><tr align=center valign=middle><td>&nbsp;<td>&nbsp;";
    for($j = 0; $j < $jmax; $j++) {
	print "<td>lambda = $lambda_xzyk[$j]";
    }
    print "</tr>\n" ;    
}
sub write_tabtail_htm {
    print "</table>\n" ;
    print "</body></html>\n" ;
}
sub write_rowhead_htm {
    print "<tr align=left valign=middle><td> " ;
    print "<td>P/D       <br>sd(P/D)<br>
               R         <br>sd(R)<br>
               rf        <br>sd(rf)<br>
               ep        <br>
               corr(x,R) <br>
               Sharpe    <br>\n";
}
sub write_rec_htm {
    $string = $_[0] ;
    ($NOB,$PD,$R,$rf,$ep,$SPD,$SR,$Srf,$Sep,$corr,$sha)
	= split(/\s+/,$string) ;
    if(defined($R)) {
	printf 
	"<td align=center>%1.2f<br>%1.2f<br>%1.2f<br>%1.2f<br>%1.2f<br>%1.2f<br>%1.2f<br>%1.2f<br>%1.2f\n",
	$PD,$SPD,$R,$SR,$rf,$Srf,$ep,$corr,$sha;
    } else {
	print "<td>unstable\n" ;
    }
}
